@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 1998, 2016 Oracle, IBM Corporation and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2020 Oracle, IBM Corporation and/or its affiliates. All rights reserved.
  * This program and the accompanying materials are made available under the 
  * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
  * which accompanies this distribution. 
@@ -404,6 +404,7 @@ public class LoggingLocalizationResource extends ListResourceBundle {
         { "sdo_missing_schemaLocation", "Referenced schema with uri {0} could not be processed because no schemaLocation attribute was specified."},
         { "sdo_invalid_schemaLocation", "Could not create schemaLocation [{0}] for import with uri [{1}]."},
         { "sdo_error_processing_referenced_schema", "An {0} occurred processing referenced schema with uri {1} with schemaLocation {2}."},
+        { "sdo_error_deserialization", "Unauthorized deserialization attempt with class {0}."},
         { "ox_turn_global_logging_off", " {0} Turning global session logging off."},
         { "ox_lowering_global_logging_from_default_info_to_warning", " {0} Lowering global logging from default INFO to WARNING level."},        
         { "ox_turn_session_logging_off", " {0} Turning session logging off."},
@@ -484,6 +485,7 @@ public class LoggingLocalizationResource extends ListResourceBundle {
         { "dbws_orm_metadata_read_error", "Could not read ORM metadata: [{0}]"},
         { "dbws_oxm_metadata_read_error", "Could not read OXM metadata: [{0}]"},
         { "dbws_no_wsdl_inline_schema", "Could not read WSDL inline schema: [{0}]"},
+        { "javase_version_ex_method_call", "Exception when calling method {0}: {1}" },
 
         // FINEST, FINER and FINE level messages.
         { "acquire_unit_of_work_with_argument", "acquire unit of work: {0}" },
@@ -703,8 +705,6 @@ public class LoggingLocalizationResource extends ListResourceBundle {
         { "weaver_processing_class", "Class [{0}] registered to be processed by weaver."},
         { "begin_weaving_class", "Begin weaver class transformer processing class [{0}]."},
         { "end_weaving_class", "End weaver class transformer processing class [{0}]."},
-        { "weaving_init_class_writer", "Initializing class writer for [{0}]. Class loaders: context [{1}]."},
-        { "weaving_init_compute_class_writer", "Initializing compute class writer for [{0}]. Class loaders: context [{1}] argument [{2}]."},
         { "transform_missing_class_details", "Missing class details for [{0}]."},
         { "transform_existing_class_bytes", "Using existing class bytes for [{0}]."},
         { "weaved_lazy", "Weaved lazy (ValueHolder indirection) [{0}]."},
@@ -712,13 +712,6 @@ public class LoggingLocalizationResource extends ListResourceBundle {
         { "weaved_changetracker", "Weaved change tracking (ChangeTracker) [{0}]."},
         { "weaved_persistenceentity", "Weaved persistence (PersistenceEntity) [{0}]."},
         { "weaved_rest", "Weaved REST [{0}]."},
-        { "class_weaver_add_get_set_add_get", "Adding _persistence_get() method into [{0}]." },
-        { "class_weaver_add_get_set_add_set", "Adding _persistence_set() method into [{0}]." },
-        { "class_weaver_visit_end_do","Visiting the end of the class [{0}]." },
-        { "class_weaver_visit_end_skip","Skipping the end of the class [{0}]." },
-        { "class_weaver_visit_end_internal","Processing internal optimizations [{0}]." },
-        { "weaving_call_persistence_get", "Calling [{0}]._persistence_get. Class loaders: context [{1}], instance [{2}]"},
-        { "weaving_call_persistence_set", "Calling [{0}]._persistence_set. Class loaders: context [{1}], instance [{2}]"},
         { "cmp_init_invoke_predeploy", "JavaSECMPInitializer - predeploying {0}."},
         { "cmp_init_register_transformer", "JavaSECMPInitializer - registering transformer for {0}."},
         { "cmp_init_tempLoader_created", "JavaSECMPInitializer - created temporary ClassLoader: {0}."},
@@ -825,7 +818,8 @@ public class LoggingLocalizationResource extends ListResourceBundle {
         { "jaxp_sec_disabled", "Xml Security disabled, no JAXP {0} external access configuration necessary." },
         { "jaxp_sec_explicit", "Detected explicitly JAXP configuration, no JAXP {0} external access configuration necessary." },
         { "jaxp_sec_prop_supported", "Property {0} is supported and has been successfully set by used JAXP implementation." },
-        { "jaxp_sec_prop_not_supported", "Property {0} is not supported by used JAXP implementation." }
+        { "jaxp_sec_prop_not_supported", "Property {0} is not supported by used JAXP implementation." },
+        { "javase_version_ex_method_not_found", "Method {0} was not found in {1}" }
     };
 
     /**
