@@ -8,15 +8,16 @@
  * http://www.eclipse.org/org/documents/edl-v10.php.
  *
  * Contributors:
- *     tware - added WebSphere_7_Platform for EclipseLink 2.0
+ *     Oracle - initial API and implementation from Oracle TopLink
  ******************************************************************************/  
 package org.eclipse.persistence.internal.sessions.factories.model.platform;
 
 /**
  * INTERNAL:
  */
-public class WebSphere_7_0_PlatformConfig extends ServerPlatformConfig {
-    public WebSphere_7_0_PlatformConfig() {
-        super("org.eclipse.persistence.platform.server.was.WebSphere_7_Platform");
+public class WebSphere_6_0_PlatformConfig extends ServerPlatformConfig {
+    public WebSphere_6_0_PlatformConfig() {
+        super("org.eclipse.persistence.platform.server.was.WebSpherePlatform");
+        isSupported = false;
     }
 }
