@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 1998, 2012 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2020 Oracle and/or its affiliates. All rights reserved.
  * This program and the accompanying materials are made available under the
  * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
  * which accompanies this distribution.
@@ -19,6 +19,10 @@ import org.eclipse.persistence.internal.helper.ClassConstants;
 import org.eclipse.persistence.sdo.types.*;
 import org.eclipse.persistence.sdo.helper.SDOTypeHelper;
 
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+
 /**
  * <p><b>Purpose</b>: Maintain constants in one class
  * <p><b>Responsibilities</b>:<ul>
@@ -344,6 +348,14 @@ public class SDOConstants {
     /** Search string concatenated from default package for type generation and the package separator dot */
     public static final String JAVA_TYPE_GENERATION_DEFAULT_PACKAGE_NAME_SEARCH = JAVA_TYPEGENERATION_DEFAULT_PACKAGE_NAME + JAVA_PACKAGE_NAME_SEPARATOR;
 
+    /** List of the classes allowed to deserialize in SDO*/
+    public static final Set<String> ALLOWED_DESERIALIZATION_CLASS_NAMES = Collections.unmodifiableSet(
+            new HashSet() {{
+                add(org.eclipse.persistence.sdo.SDOExternalizableDelegator.class.getName());
+                add(org.eclipse.persistence.sdo.AbstractExternalizableDelegator.class.getName());
+                add(java.util.ArrayList.class.getName());
+            }});
+
     static {
         if(null != sdoTypeHelper) {
             sdoTypeHelper.reset();
